LayoutItem

Enum LayoutItem 

pub enum LayoutItem<K, V, P> {
    Node {
        id: K,
        center: V,
        size: V,
    },
    Polyline {
        from: K,
        to: K,
        points: P,
    },
}
A geometric item within an arrangement of a Weave’s content.

Variants



Node

Computed geometry for a Node.

Fields

id: K

Node identifier.

center: V

Node center position.

size: V

Node size.



Polyline

Computed geometry for a connection between Nodes.

Fields

from: K

Parent node where the connection starts.

to: K

Child node where the connection ends.

points: P

Points for a polyline routed between the two nodes.