BookmarkableWeave

Trait BookmarkableWeave 

pub trait BookmarkableWeave<K, N, T>: Weave<K, N, T>
where K: Hash + Copy + Eq + Ord, N: Node<K, T>,
{ type Bookmarks; // Required methods fn bookmarks(&self) -> &Self::Bookmarks; fn contains_bookmark(&self, id: &K) -> bool; fn set_node_bookmarked_status(&mut self, id: &K, value: bool) -> bool; }
A Weave where nodes can be bookmarked.

Required Associated Types

type Bookmarks

Identifiers of bookmarked nodes.

Required Methods

fn bookmarks(&self) -> &Self::Bookmarks

Returns a reference to the identifiers of bookmarked nodes.

fn contains_bookmark(&self, id: &K) -> bool

Returns true if the Weave contains a bookmarked node with the specified identifier.

fn set_node_bookmarked_status(&mut self, id: &K, value: bool) -> bool

Sets the bookmarked status of a node with the specified identifier.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<K, T, M, S> BookmarkableWeave<K, DependentNode<K, T, S>, T> for DependentWeave<K, T, M, S>
where K: Hash + Copy + Eq + Ord, S: BuildHasher + Default + Clone,

Source

impl<K, T, M, S> BookmarkableWeave<K, IndependentNode<K, T, S>, T> for IndependentWeave<K, T, M, S>

Source

impl<W, K, N, T, M> BookmarkableWeave<K, N, T> for LoggedWeave<W, K, N, T, M>
where W: BookmarkableWeave<K, N, T>, K: Hash + Copy + Eq + Ord, N: Node<K, T> + Clone,

Source

impl<W, K, N, T> BookmarkableWeave<K, N, T> for CountedWeave<W, K, N, T>
where W: BookmarkableWeave<K, N, T>, K: Hash + Copy + Eq + Ord, N: Node<K, T>,