ImmutableBookmarkableWeave

Trait ImmutableBookmarkableWeave 

pub trait ImmutableBookmarkableWeave<K, N, T>: ImmutableWeave<K, N, T>
where K: Hash + Copy + Eq + Ord, N: Node<K, T>,
{ type Bookmarks; // Required methods fn bookmarks(&self) -> &Self::Bookmarks; fn contains_bookmark(&self, id: &K) -> bool; }
An ImmutableWeave where nodes can be bookmarked.

Required Associated Types

type Bookmarks

Identifiers of bookmarked nodes.

Required Methods

fn bookmarks(&self) -> &Self::Bookmarks

Returns a reference to the identifiers of bookmarked nodes.

fn contains_bookmark(&self, id: &K) -> bool

Returns true if the Weave contains a bookmarked node with the specified identifier.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<K, T, M, S> ImmutableBookmarkableWeave<<K as Archive>::Archived, ArchivedDependentNode<K, T, S>, <T as Archive>::Archived> for ArchivedDependentWeave<K, T, M, S>
where K: Archive + Hash + Copy + Eq + Ord, <K as Archive>::Archived: Hash + Copy + Eq + Ord + 'static, T: Archive, M: Archive, S: BuildHasher + Default + Clone,

Available on crate feature rkyv only.
Source

impl<K, T, M, S> ImmutableBookmarkableWeave<<K as Archive>::Archived, ArchivedIndependentNode<K, T, S>, <T as Archive>::Archived> for ArchivedIndependentWeave<K, T, M, S>
where K: Archive + Hash + Copy + Eq + Ord, <K as Archive>::Archived: Hash + Copy + Eq + Ord + 'static, T: Archive + IndependentContents, M: Archive, S: BuildHasher + Default + Clone,

Available on crate feature rkyv only.