pub struct VersionedBytes<'a> {
pub format_identifier: [u8; 24],
pub version: u64,
pub data: &'a [u8],
}Expand description
A set of bytes accompanied by file header information.
Buffers deserialized using rkyv must be aligned to 16-byte boundaries. VersionedBytes is capable of preserving 16-byte memory alignment if the backing byte buffer is correctly aligned.
Fields
format_identifier: [u8; 24]The magic bytes at the start of the file indicating the format used.
version: u64The format version stored within the header.
data: &'a [u8]The data following the header.
Implementations
Sourceimpl<'a> VersionedBytes<'a>
impl<'a> VersionedBytes<'a>
Sourcepub fn try_from_bytes(
value: &'a [u8],
format_identifier: [u8; 24],
) -> Option<Self>
pub fn try_from_bytes( value: &'a [u8], format_identifier: [u8; 24], ) -> Option<Self>
Tries to deserialize a VersionedBytes struct from a byte array.
This can fail in the following cases:
- The specified
format_identifierdoes not match the first 24 bytes of the byte array - The byte array is less than 32 bytes long
Sourcepub const fn output_length(&self) -> usize
pub const fn output_length(&self) -> usize
The total length in bytes after serialization.