CountedWeave

Struct CountedWeave 

pub struct CountedWeave<W, K, N, T>
where W: Weave<K, N, T>, K: Hash + Copy + Eq + Ord, N: Node<K, T>,
{ pub weave: W, pub count: WeaveActionCount, /* private fields */ }
A Weave wrapper which logs the number of actions successfully performed on the inner Weave.

See WeaveActionCount for the complete list of loggable actions.

Fields

weave: W

The Weave being wrapped.

Actions performed directly on the inner Weave (without using the wrapper’s functions) are not logged.

count: WeaveActionCount

The number of actions that were performed on the attached Weave.

Implementations

Source

impl<W, K, N, T> CountedWeave<W, K, N, T>
where W: Weave<K, N, T>, K: Hash + Copy + Eq + Ord, N: Node<K, T>,

pub const fn new(weave: W, count: WeaveActionCount) -> Self

Creates a CountedWeave from a Weave and WeaveActionCount pair.

pub fn from_weave(weave: W) -> Self

Creates a CountedWeave from a Weave.

pub fn into_weave(self) -> W

Converts a CountedWeave into it’s inner Weave.

pub const fn as_weave(&self) -> &W

Returns a reference to the inner Weave.

pub const fn as_count(&self) -> &WeaveActionCount

Returns a reference to the inner WeaveActionCount.

pub fn reset_count(&mut self)

Resets the inner WeaveActionCount to zero.