WeaveActionCount

Struct WeaveActionCount 

#[non_exhaustive]
pub struct WeaveActionCount {
Show 15 fields pub add_node: usize, pub set_node_active_status: usize, pub set_node_bookmarked_status: usize, pub remove_node: usize, pub remove_all_nodes: usize, pub metadata_mut: usize, pub sort_node_children: usize, pub sort_roots: usize, pub sort_bookmarks: usize, pub set_active_path: usize, pub move_node: usize, pub get_contents_mut: usize, pub split_node: usize, pub merge_with_parent: usize, pub other: usize,
}
The number of times actions changing the outwardly facing state of a Weave were performed.

When possible, actions map to a function of the Weave trait or its supertraits. Some actions not logged here may change the Weave’s inner state but not its outwardly facing state.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
add_node: usizeset_node_active_status: usizeset_node_bookmarked_status: usizeremove_node: usizeremove_all_nodes: usizemetadata_mut: usizesort_node_children: usizesort_roots: usizesort_bookmarks: usizeset_active_path: usizemove_node: usizeget_contents_mut: usizesplit_node: usizemerge_with_parent: usizeother: usize

User defined; Not incremented/decremented by the CountedWeave wrapper or WeaveActionCount functions.

Implementations

Source

impl WeaveActionCount

pub fn new() -> Self

Creates a new action count initalized to zero.

pub fn reset(&mut self)

Resets all action counts to zero.

pub const fn total_count(&self) -> usize

Returns the sum of all action counts.

pub const fn increment<K, N, T, M>(&mut self, action: &WeaveAction<K, N, T, M>)
where K: Hash + Copy + Eq + Ord, N: Node<K, T>,

Increments the action count corresponding to the WeaveAction’s type.

pub const fn decrement<K, N, T, M>(&mut self, action: &WeaveAction<K, N, T, M>)
where K: Hash + Copy + Eq + Ord, N: Node<K, T>,

Decrements the action count corresponding to the WeaveAction’s type.