pub struct DependentWeave<K, T, M, S>{
pub metadata: M,
/* private fields */
}Expand description
A tree-based Weave where each Node depends on the contents of the previous Node.
For best performance, it is recommended that you use random node identifiers and the Hasher implementation from the nohash-hasher crate. If your node identifiers end with random data (such as ULIDs in their raw representation), use the hash_hasher crate instead.
Fields
metadata: MThe metadata associated with the weave.
Implementations
Sourceimpl<K, T, M, S> DependentWeave<K, T, M, S>
impl<K, T, M, S> DependentWeave<K, T, M, S>
Sourcepub fn new(metadata: M) -> Self
pub fn new(metadata: M) -> Self
Creates a new, empty DependentWeave.
Contracts
Post-condition: ret.nodes.is_empty()
Post-condition: ret.validate()
Sourcepub fn with_capacity(capacity: usize, metadata: M) -> Self
pub fn with_capacity(capacity: usize, metadata: M) -> Self
Creates a new, empty DependentWeave with at least the specified capacity.
This function over-allocates for worst-case memory usage rather than average-case.
Contracts
Post-condition: ret.nodes.is_empty()
Post-condition: ret.validate()
Sourcepub fn capacity(&self) -> usize
pub fn capacity(&self) -> usize
Returns the worst-case number of nodes that the weave can hold without reallocating.
May be lower than self.len().
Sourcepub fn reserve(&mut self, additional: usize)
pub fn reserve(&mut self, additional: usize)
Reserves capacity for at least additional more nodes.
Sourcepub fn shrink_to_fit(&mut self)
pub fn shrink_to_fit(&mut self)
Shrinks the capacity of the weave as much as possible.