DependentWeave

Struct DependentWeave 

pub struct DependentWeave<K, T, M, S>
where K: Hash + Copy + Eq + Ord, S: BuildHasher + Default + Clone,
{ pub metadata: M, /* private fields */ }
A tree-based Weave where each Node depends on the contents of the previous Node.

Fields

metadata: M

The metadata associated with the weave.

Implementations

Source

impl<K, T, M, S> DependentWeave<K, T, M, S>
where K: Hash + Copy + Eq + Ord, S: BuildHasher + Default + Clone,

pub fn with_capacity(capacity: usize, metadata: M) -> Self

Creates a new, empty DependentWeave with at least the specified capacity.

Contracts

Post-condition: ret.nodes.is_empty()

Post-condition: ret.validate()

pub fn capacity(&self) -> usize

Returns the number of nodes the weave can hold without reallocating.

pub fn reserve(&mut self, additional: usize)

Reserves capacity for at least additional more nodes.

Contracts

Post-condition: old(self.nodes.keys().copied().collect::<HashSet<_>>()) == self.nodes.keys().copied().collect ::< HashSet < _ >> ()

Post-condition: old(self.roots.clone()) == self.roots

Post-condition: old(self.active) == self.active

Post-condition: old(self.bookmarked.clone()) == self.bookmarked

Invariant: self.validate()

pub fn shrink_to(&mut self, min_capacity: usize)

Shrinks the capacity of the weave with a lower limit.

Contracts

Post-condition: old(self.nodes.keys().copied().collect::<HashSet<_>>()) == self.nodes.keys().copied().collect ::< HashSet < _ >> ()

Post-condition: old(self.roots.clone()) == self.roots

Post-condition: old(self.active) == self.active

Post-condition: old(self.bookmarked.clone()) == self.bookmarked

Invariant: self.validate()

Source

impl<K, T, M, S> DependentWeave<K, T, M, S>
where K: Hash + Copy + Eq + Ord, S: BuildHasher + Default + Clone,

pub fn validate(&self) -> bool

Validates that the weave is internally consistent.