pub trait ActivePathWeave<K, N, T>: Weave<K, N, T>{
type Active;
// Required methods
fn active(&self) -> &Self::Active;
fn set_active_path(&mut self, active: impl Iterator<Item = K>);
}Required Associated Types
Required Methods
Sourcefn set_active_path(&mut self, active: impl Iterator<Item = K>)
fn set_active_path(&mut self, active: impl Iterator<Item = K>)
Replaces the currently active path with the specified set of node IDs.
If the new active path would result in internal inconsistency, this function will correct the path in an implementation-specific manner.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".