pub trait BookmarkableWeave<K, N, T>: Weave<K, N, T>{
type Bookmarks;
// Required methods
fn bookmarks(&self) -> &Self::Bookmarks;
fn contains_bookmark(&self, id: &K) -> bool;
fn set_node_bookmarked_status(&mut self, id: &K, value: bool) -> bool;
}Expand description
A Weave where nodes can be bookmarked.
Required Associated Types
Required Methods
Sourcefn bookmarks(&self) -> &Self::Bookmarks
fn bookmarks(&self) -> &Self::Bookmarks
Returns a reference to the identifiers of bookmarked nodes.
Sourcefn contains_bookmark(&self, id: &K) -> bool
fn contains_bookmark(&self, id: &K) -> bool
Returns true if the Weave contains a bookmarked node with the specified identifier.
Sourcefn set_node_bookmarked_status(&mut self, id: &K, value: bool) -> bool
fn set_node_bookmarked_status(&mut self, id: &K, value: bool) -> bool
Sets the bookmarked status of a node with the specified identifier.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".