pub trait DiscreteWeave<K, N, T>: Weave<K, N, T>{
// Required methods
fn split_node(&mut self, id: &K, at: usize, new_id: K) -> bool;
fn merge_with_parent(&mut self, id: &K) -> Option<K>;
}Required Methods
Sourcefn split_node(&mut self, id: &K, at: usize, new_id: K) -> bool
fn split_node(&mut self, id: &K, at: usize, new_id: K) -> bool
Splits a node with the specified identifier at the given index, creating a new child node with the identifier new_id.
Returns false if splitting the node failed or the node could not be found.
Sourcefn merge_with_parent(&mut self, id: &K) -> Option<K>
fn merge_with_parent(&mut self, id: &K) -> Option<K>
Merges a node with the specified identifier with its parent, with the newly merged node inheriting the parent’s identifier.
Returns the identifier of the merged node if merging was successful.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".