pub trait ImmutableBookmarkableWeave<K, N, T>: ImmutableWeave<K, N, T>{
type Bookmarks;
// Required methods
fn bookmarks(&self) -> &Self::Bookmarks;
fn contains_bookmark(&self, id: &K) -> bool;
}Expand description
An ImmutableWeave where nodes can be bookmarked.
Required Associated Types
Required Methods
Sourcefn bookmarks(&self) -> &Self::Bookmarks
fn bookmarks(&self) -> &Self::Bookmarks
Returns a reference to the identifiers of bookmarked nodes.
Sourcefn contains_bookmark(&self, id: &K) -> bool
fn contains_bookmark(&self, id: &K) -> bool
Returns true if the Weave contains a bookmarked node with the specified identifier.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
Sourceimpl<K, T, M, S> ImmutableBookmarkableWeave<<K as Archive>::Archived, ArchivedDependentNode<K, T, S>, <T as Archive>::Archived> for ArchivedDependentWeave<K, T, M, S>
Available on crate feature rkyv only.
impl<K, T, M, S> ImmutableBookmarkableWeave<<K as Archive>::Archived, ArchivedDependentNode<K, T, S>, <T as Archive>::Archived> for ArchivedDependentWeave<K, T, M, S>
Available on crate feature
rkyv only.Sourceimpl<K, T, M, S> ImmutableBookmarkableWeave<<K as Archive>::Archived, ArchivedIndependentNode<K, T, S>, <T as Archive>::Archived> for ArchivedIndependentWeave<K, T, M, S>
Available on crate feature rkyv only.
impl<K, T, M, S> ImmutableBookmarkableWeave<<K as Archive>::Archived, ArchivedIndependentNode<K, T, S>, <T as Archive>::Archived> for ArchivedIndependentWeave<K, T, M, S>
Available on crate feature
rkyv only.