pub trait Node<K, T>{
type From;
type To;
// Required methods
fn id(&self) -> K;
fn from(&self) -> &Self::From;
fn to(&self) -> &Self::To;
fn is_active(&self) -> bool;
fn contents(&self) -> &T;
}Expand description
An item within a Weave which can be connected to other items.
Required Associated Types
Required Methods
Sourcefn from(&self) -> &Self::From
fn from(&self) -> &Self::From
Returns a reference to the identifiers corresponding to the node’s parents.
Sourcefn to(&self) -> &Self::To
fn to(&self) -> &Self::To
Returns a reference to the identifiers corresponding to the node’s children.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
Sourceimpl<K, T, S> Node<<K as Archive>::Archived, <T as Archive>::Archived> for ArchivedDependentNode<K, T, S>
Available on crate feature rkyv only.
impl<K, T, S> Node<<K as Archive>::Archived, <T as Archive>::Archived> for ArchivedDependentNode<K, T, S>
Available on crate feature
rkyv only.Sourceimpl<K, T, S> Node<<K as Archive>::Archived, <T as Archive>::Archived> for ArchivedIndependentNode<K, T, S>
Available on crate feature rkyv only.
impl<K, T, S> Node<<K as Archive>::Archived, <T as Archive>::Archived> for ArchivedIndependentNode<K, T, S>
Available on crate feature
rkyv only.