pub struct CountedWeave<W, K, N, T>{
pub weave: W,
pub count: WeaveActionCount,
/* private fields */
}Expand description
A Weave wrapper which logs the number of actions successfully performed on the inner Weave.
See WeaveActionCount for the complete list of loggable actions.
Fields
weave: WThe Weave being wrapped.
Actions performed directly on the inner Weave (without using the wrapper’s functions) are not logged.
count: WeaveActionCountThe number of actions that were performed on the attached Weave.
Implementations
Sourceimpl<W, K, N, T> CountedWeave<W, K, N, T>
impl<W, K, N, T> CountedWeave<W, K, N, T>
Sourcepub const fn new(weave: W, count: WeaveActionCount) -> Self
pub const fn new(weave: W, count: WeaveActionCount) -> Self
Creates a CountedWeave from a Weave and WeaveActionCount pair.
Sourcepub fn from_weave(weave: W) -> Self
pub fn from_weave(weave: W) -> Self
Creates a CountedWeave from a Weave.
Sourcepub fn into_weave(self) -> W
pub fn into_weave(self) -> W
Converts a CountedWeave into it’s inner Weave.
Sourcepub const fn as_count(&self) -> &WeaveActionCount
pub const fn as_count(&self) -> &WeaveActionCount
Returns a reference to the inner WeaveActionCount.
Sourcepub fn reset_count(&mut self)
pub fn reset_count(&mut self)
Resets the inner WeaveActionCount to zero.